#
# spec file for package xf86-video-savage
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-savage
Version:        2.4.1
Release:        1.3
Summary:        S3 Savage video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
BuildRequires:  Mesa-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(libdrm) >= 2.0
BuildRequires:  pkgconfig(pciaccess) >= 0.10
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86driproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.1.0
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v00005333d*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390 s390x
%x11_abi_videodrv_req

%description
savage is an Xorg driver for S3 Savage video cards.

2D, 3D, and Xv acceleration is supported on all chips except the
Savage2000 (2D only). Dualhead operation is supported on MX, IX, and
SuperSavage chips.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%defattr(-,root,root)
%doc ChangeLog README.md
%license COPYING
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/savage_drv.so
%{_datadir}/man/man4/savage.4%{?ext_man}

%changelog
* Mon Mar 25 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.4.1
  * This release fixes a failure to build with gcc 14 and cleans
    up several other compiler warnings.
* Mon Apr 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.4.0
  * This release improves support for building with Xorg 1.19 and later.
- supersedes u_Add-check-for-max-HV-Value-to-ValidMode-hook.patch
* Fri Jun 22 2018 sndirsch@suse.com
- u_Add-check-for-max-HV-Value-to-ValidMode-hook.patch
  * Add check for max[HV]Value to ValidMode hook, since this
    functionality has been removed from xorg-server 1.20
* Thu Jan 19 2017 sndirsch@suse.com
- Update to version 2.3.9:
  * Adapt Block/WakeupHandler signature for ABI 23
  * Disable tiling on SuperSavage by default
- supersedes U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch,
  u_Disable-tiling-on-SuperSavage-Novell-Bugzilla-805380.patch
* Wed Nov 30 2016 sndirsch@suse.com
- U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
  * Adapt Block/WakeupHandler signature for ABI 23
* Wed Nov 18 2015 eich@suse.com
- remove:
  u_Include-xf86Modes.h-to-use-functions-from-hw-xfree86.patch
  * since 2.3.8 xf86Modes.h is included in savage_driver.h.
* Fri May  8 2015 sndirsch@suse.com
- Update to version 2.3.8
  * Use own thunk function instead of vgaHW*Weak
  * dri: Stop (uselessly) initializing the ValidateTree hooks
  * Include xf86Modes.h to use functions from hw/xfree86/modes/xf86Modes.c.
  * Fix compiler warnings with recent X servers
- deprecates U_dri-Stop-uselessly-initializing-the-ValidateTree-hoo.patch
* Fri Feb  6 2015 sndirsch@suse.com
- U_dri-Stop-uselessly-initializing-the-ValidateTree-hoo.patch
  * fixes build against xorg-server 1.17
* Mon Dec  2 2013 sndirsch@suse.com
- u_Include-xf86Modes.h-to-use-functions-from-hw-xfree86.patch
  * fixes build against xorg-server 1.15
* Tue Oct  1 2013 sndirsch@suse.com
- Update to version 2.3.7
  * small bugfix for video playback on MX/IX/SuperSavage
  * usual catch-up to the ever-changing xserver, build and run on
    1.14, and default to EXA now that the xserver does not support
    XAA anymore.
- obsoletes U_savage-move-compat-api.h-down-to-proper-place.patch,
  U_savage-fix-default-accel-arch-when-built-with-no-XAA.patch
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Sat Mar  2 2013 sndirsch@suse.com
- u_Disable-tiling-on-SuperSavage-Novell-Bugzilla-805380.patch
  * Disable tiling on SuperSavage (Novell Bugzilla #805380)
- obsoletes
  u_Disable-tiling-on-SuperSavage-IXC-64-Novell-Bugzilla.patch
* Thu Feb 28 2013 sndirsch@suse.com
- u_Disable-tiling-on-SuperSavage-IXC-64-Novell-Bugzilla.patch
  * disables tiling on SuperSavage/IXC 64 (bnc#805380)
* Mon Feb 25 2013 sndirsch@suse.com
- U_savage-move-compat-api.h-down-to-proper-place.patch
  * This screws up when DRI isn't enabled.
- U_savage-fix-default-accel-arch-when-built-with-no-XAA.patch
  * fix default accel arch when built with no XAA (bnc#805380?)
* Sun Sep  2 2012 zaitor@opensuse.org
- Update to version 2.3.6:
  + Make build with no xaa server.
- Changes since version 2.3.5:
  + i2c drop xf86Screens usage.
  + Port to new compat API
  + Refactor BIOS modes retrieval to call VBEGetVBEInfo only once.
    Otherwise, calling it twice would trigger a VBE bug when using
    xserver 1.12.
* Fri Jun  1 2012 sndirsch@suse.com
- remove hw supplements (bnc#764395)
* Wed May 23 2012 crrodriguez@opensuse.org
- Add proper "Supplements" so the driver is picked up by
  the package manager when the user has the proper hardware.
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 2.3.4:
  + Untangle XF86DRI from the driver-specific DRI define
  + Merge almost identical code in SAVAGEInitVisualConfigs
    (fdo#9961)
  + Fix for new vgahw ABI
  + Fall back to shadowfb if XAA is unavailable
- Changes from version 2.3.3:
  + savage: Warn if broken drm maps are detected (fdo#32511)
  + savage: Fix Xv scaling on non-native resolutions (lp#670790)
  + Other bugs fixed: bko#4607
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-savage from xorg-x11-driver-video.
  Initial version: 2.3.2.
